@@ -68,7 +68,7 @@ Signac <- function(E, R = 'default', spring.dir = NULL, N = 100, num.cores = 1,
   
   if (flag){
     default.assay <- Seurat::DefaultAssay(E)
-    edges = E@graphs[[which(grepl(paste0("_", graph.used), names(E@graphs)))]]
+    edges = E@graphs[[which(grepl(paste0(default.assay, "_", graph.used), names(E@graphs)))]]
   }
   
   if (verbose)
